@@ -12,10 +12,10 @@ from ..utils import _unique_key_to_request_id
 class RequestQueue:
     def __init__(self, id: [None, str], config: Configuration):
         self._id = id or config.get_config_value('REQUEST_QUEUE_ID', 'default')
-        self._config = config
+        self.config = config
         self._lock = threading.Lock()
         self.request_queues_path = os.path.join(
-            self._config.base_dir,
+            self.config.base_dir,
             'request_queues',
             self._id
         )
